searchData={"items":[{"type":"module","title":"Slack.API","doc":"Slack Web API.","ref":"Slack.API.html"},{"type":"function","title":"Slack.API.client/1","doc":"Req client for Slack API.","ref":"Slack.API.html#client/1"},{"type":"function","title":"Slack.API.get/3","doc":"GET from Slack API.","ref":"Slack.API.html#get/3"},{"type":"function","title":"Slack.API.post/3","doc":"POST to Slack API.","ref":"Slack.API.html#post/3"},{"type":"function","title":"Slack.API.stream/4","doc":"GET pages from Slack API as a `Stream`.\n\nYou can start at a cursor if you pass in `:next_cursor` as one of the `args`.\nNote that it is assumed to be an atom key. If you use a string key you'll\nend up with `next_cursor` parameter twice.","ref":"Slack.API.html#stream/4"},{"type":"behaviour","title":"Slack.Bot","doc":"The Slack Bot.","ref":"Slack.Bot.html"},{"type":"callback","title":"Slack.Bot.handle_event/2","doc":"Handle the event from Slack.\nReturn value is ignored.","ref":"Slack.Bot.html#c:handle_event/2"},{"type":"macro","title":"Slack.Bot.send_message/2","doc":"Send a message to a channel.\n\nThe `message` can be just the message text, or a `t:map/0` of properties that\nare accepted by Slack's `chat.postMessage` API endpoint.","ref":"Slack.Bot.html#send_message/2"},{"type":"type","title":"Slack.Bot.t/0","doc":"","ref":"Slack.Bot.html#t:t/0"},{"type":"module","title":"Slack.Supervisor","doc":"Supervisor that starts the stuff that needs to run.","ref":"Slack.Supervisor.html"},{"type":"function","title":"Slack.Supervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Slack.Supervisor.html#child_spec/1"},{"type":"function","title":"Slack.Supervisor.start_link/1","doc":"Start the Slack bot supervisor.\nSee `README` for instructions.","ref":"Slack.Supervisor.html#start_link/1"},{"type":"extras","title":"Slack","doc":"# Slack\n\n[![Tests](https://github.com/ryanwinchester/slack_elixir/actions/workflows/ci.yml/badge.svg)](https://github.com/ryanwinchester/slack_elixir/actions/workflows/ci.yml)\n [![Hex.pm](https://img.shields.io/hexpm/v/slack_elixir)](https://hex.pm/packages/slack_elixir)\n [![Hex.pm](https://img.shields.io/hexpm/dt/slack_elixir)](https://hex.pm/packages/slack_elixir)\n [![Hex.pm](https://img.shields.io/hexpm/l/slack_elixir)](https://github.com/ryanwinchester/slack_elixir/blob/main/LICENSE)\n\nThis is for creating Slack applications or bots in Elixir.\n\n#","ref":"readme.html"},{"type":"extras","title":"Why? - Slack","doc":"The existing libraries I was looking at use the deprecated RTM API, and no longer work with\nnew apps or bots.\n\n#","ref":"readme.html#why"},{"type":"extras","title":"What? - Slack","doc":"To listen for subscribed events, it uses [**Socket Mode**](https://api.slack.com/apis/connections/socket) to connect to Slack.\nIt has some pros and cons, so please [read up on it](https://api.slack.com/apis/connections/socket) (and pay attention to the info blocks).\n\nIt's a relatively thin wrapper, which keeps it flexible and easy to maintain.\n\n#","ref":"readme.html#what"},{"type":"extras","title":"How - Slack","doc":"- connects to Slack using a websocket connection to listen for your event subscriptions.\n - uses the [Web API](https://api.slack.com/web) to send messages, etc.\n - uses dynamically supervised gen servers to handle each channel's message rate-limiting with a message queue\n   per channel.","ref":"readme.html#how"},{"type":"extras","title":"Installation - Slack","doc":"Add `slack_elixir` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:slack_elixir, \"~> 1.0.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Setup - Slack","doc":"You will need to:\n\n  - Create a Slack app for your workspace\n  - Add permissions (scopes)\n  - Connect it to your workspace\n  - Get an OAuth Bot Token (will have the scopes you defined)\n  - Enable Socket Mode\n  - Get an app-level token with `connections:write` scope\n  - Add Event Subscriptions\n\nSee below for some minimum required scopes and event subscriptions. You will\nneed to add more scopes and subscriptions depending on what you want to do.\n\n##","ref":"readme.html#setup"},{"type":"extras","title":"Required Bot Token scopes: - Slack","doc":"- `channels:history`\n - `channels:read`\n - `groups:read`\n - `mpim:read`\n - `im:read`\n\n##","ref":"readme.html#required-bot-token-scopes"},{"type":"extras","title":"Required Bot Event Subscriptions - Slack","doc":"- `message.channels`\n - `member_joined_channel`\n - `channel_left`","ref":"readme.html#required-bot-event-subscriptions"},{"type":"extras","title":"Usage - Slack","doc":"Write the Bot module:\n  \n```elixir\ndefmodule MyApp.Slackbot do\n  use Slack.Bot\n\n  require Logger\n\n  @impl true\n  # A silly example of old-school style bot commands.\n  def handle_event(\"message\", %{\"text\" => \"!\"   command, \"channel\" => channel, \"user\" => user}) do\n    case command do\n      \"roll\" ->\n        send_message(channel, \"  rolled a #{Enum.random(1..6)}\")\n\n      \"echo \"   text ->\n        send_message(channel, text)\n\n      _ ->\n        send_message(channel, \"Unknown command: #{command}\")\n    end\n  end\n\n  def handle_event(\"message\", %{\"channel\" => channel, \"text\" => text, \"user\" => user}) do\n    if String.match?(text, ~r/hello/i) do\n      send_message(channel, \"Hello!  \")\n    end\n  end\n\n  def handle_event(type, payload) do\n    Logger.debug(\"Unhandled #{type} event: #{inspect(payload)}\")\n    :ok\n  end\nend\n```\n\nThen you start the Slack Supervisor in your application's supervision tree.\n\nFor example:\n\n```elixir\n  def start(_type, _args) do\n    # Often, you'd fetch this from application env,\n    # set in `config/runtime.exs`, instead of like this.\n    config = [\n      app_token: \"MY_SLACK_APP_TOKEN\",\n      bot_token: \"MY_SLACK_BOT_TOKEN\",\n      bot: MyApp.SlackBot\n    ]\n\n    children = [\n      # ...\n      {Slack.Supervisor, config}\n    ]\n\n    opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\n```","ref":"readme.html#usage"},{"type":"extras","title":"Journey to v1.0 (Things that may or may not be added) - Slack","doc":"PRs welcome!\n\n- [x] **Socket Mode** for events\n- [x] Web API POST requests\n- [x] Web API GET requests\n- [x] Message Server per channel (rate-limited to 1 message per second per channel).","ref":"readme.html#journey-to-v1-0-things-that-may-or-may-not-be-added"}],"content_type":"text/markdown"}